@@ -13,17 +13,18 @@
 ##############################################################################
 """FTP server
 """
+import zope.interface
 from zope.app.publication.ftp import FTPPublication
 from zope.app.publication.interfaces import IPublicationRequestFactory
 from zope.publisher.ftp import FTPRequest
 from zope.server.ftp.logger import CommonFTPActivityLogger
 from zope.server.ftp.publisher import PublisherFTPServer
+
 from zope.app.server.servertype import ServerType
-import zope.interface
 
 
 @zope.interface.implementer(IPublicationRequestFactory)
-class FTPRequestFactory(object):
+class FTPRequestFactory:
     """FTP Request factory
 
     FTP request factories for a given database create FTP requests with
