@@ -17,21 +17,11 @@ import logging
 import unittest
 
 from ZConfig.components.logger import loghandler
+from ZConfig.components.logger.tests.support import LoggingTestHelper
 
-try:
-    # ZConfig < 2.9.2
-    from ZConfig.components.logger.tests.test_logger import LoggingTestBase
-except ImportError:
-    try:
-        # ZConfig >= 3.4.0
-        from ZConfig.components.logger.tests.support import LoggingTestHelper
-    except ImportError:
-        # ZConfig >= 2.9.2, < 3.4.0
-        from ZConfig.components.logger.tests.test_logger import \
-            LoggingTestHelper
 
-    class LoggingTestBase(LoggingTestHelper, unittest.TestCase):
-        pass
+class LoggingTestBase(LoggingTestHelper, unittest.TestCase):
+    pass
 
 
 class TestAccessLogging(LoggingTestBase):
