@@ -1,6 +1,7 @@
 import unittest
 
-from zope.app.server.main import main, load_options
+from zope.app.server.main import load_options
+from zope.app.server.main import main
 from zope.app.server.tests import capture_output
 
 
