@@ -1,10 +1,12 @@
 import unittest
 
 from zope.interface.verify import verifyObject
-from zope.app.server.servertype import IServerType
-from zope.app.server.wsgi import http, pmhttp
 from zope.server.http.wsgihttpserver import WSGIHTTPServer
 
+from zope.app.server.servertype import IServerType
+from zope.app.server.wsgi import http
+from zope.app.server.wsgi import pmhttp
+
 
 class TestWSGIServerType(unittest.TestCase):
 
