@@ -15,17 +15,16 @@
 """
 
 import zope.interface
-from zope.server.http.commonaccesslogger import CommonAccessLogger
-from zope.server.http import wsgihttpserver
-
 from zope.app.publication.httpfactory import HTTPPublicationRequestFactory
 from zope.app.wsgi import WSGIPublisherApplication
+from zope.server.http import wsgihttpserver
+from zope.server.http.commonaccesslogger import CommonAccessLogger
 
 from zope.app.server import servertype
 
 
 @zope.interface.implementer(servertype.IServerType)
-class ServerType(object):
+class ServerType:
 
     def __init__(self, factory, applicationFactory, logFactory,
                  defaultPort, defaultVerbose, defaultIP='',
@@ -38,7 +37,6 @@ class ServerType(object):
         self._defaultVerbose = defaultVerbose
         self._defaultIP = defaultIP
 
-
     def create(self, name, task_dispatcher, db, port=None,
                verbose=None, ip=None):
         'See IServerType'
@@ -56,10 +54,10 @@ class ServerType(object):
             verbose = self._defaultVerbose
 
         return self._factory(application, name, ip, port,
-                      task_dispatcher=task_dispatcher,
-                      verbose=verbose,
-                      hit_log=self._logFactory(),
-                      )
+                             task_dispatcher=task_dispatcher,
+                             verbose=verbose,
+                             hit_log=self._logFactory(),
+                             )
 
 
 http = ServerType(wsgihttpserver.WSGIHTTPServer,
